## 0.0.5 (2025-11-21)
---------------------

- update typing: on_exception now typed to OnEx
- expected_exception now defaults to Exception, was BaseException


## 0.0.4 (2025-11-18)
---------------------

- maximum_backoff -> max_backoff
- on_exception no longer may be a list - only tuple is allowed as an iterable
- add documentation/readme
- add examples.py


## 0.0.3 (2025-11-17)
- add async support
